==> haskell-postgresql-simple-0.6.5.1-101-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgresql-simple
version:              0.6.5.1
visibility:           public
id:                   postgresql-simple-0.6.5.1-7DiheDmUALmJZpTHjvNinD
key:                  postgresql-simple-0.6.5.1-7DiheDmUALmJZpTHjvNinD
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.
    (c) 2011-2018 Leon P Smith
    (c) 2018-2020 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Bryan O'\''Sullivan, Leon P Smith
synopsis:             Mid-Level PostgreSQL client library
description:
    Mid-Level PostgreSQL client library, forked from mysql-simple.

category:             Database
abi:                  d51c563167f0815419131faf9f8ed084
exposed:              True
exposed-modules:
    Database.PostgreSQL.Simple Database.PostgreSQL.Simple.Arrays
    Database.PostgreSQL.Simple.Copy Database.PostgreSQL.Simple.Cursor
    Database.PostgreSQL.Simple.Errors
    Database.PostgreSQL.Simple.FromField
    Database.PostgreSQL.Simple.FromRow
    Database.PostgreSQL.Simple.HStore
    Database.PostgreSQL.Simple.HStore.Internal
    Database.PostgreSQL.Simple.Internal
    Database.PostgreSQL.Simple.LargeObjects
    Database.PostgreSQL.Simple.Newtypes
    Database.PostgreSQL.Simple.Notification
    Database.PostgreSQL.Simple.Ok Database.PostgreSQL.Simple.Range
    Database.PostgreSQL.Simple.SqlQQ Database.PostgreSQL.Simple.Time
    Database.PostgreSQL.Simple.Time.Internal
    Database.PostgreSQL.Simple.ToField Database.PostgreSQL.Simple.ToRow
    Database.PostgreSQL.Simple.Transaction
    Database.PostgreSQL.Simple.TypeInfo
    Database.PostgreSQL.Simple.TypeInfo.Macro
    Database.PostgreSQL.Simple.TypeInfo.Static
    Database.PostgreSQL.Simple.Types Database.PostgreSQL.Simple.Vector
    Database.PostgreSQL.Simple.Vector.Unboxed

hidden-modules:
    Database.PostgreSQL.Simple.Compat
    Database.PostgreSQL.Simple.HStore.Implementation
    Database.PostgreSQL.Simple.Internal.PQResultUtils
    Database.PostgreSQL.Simple.Time.Implementation
    Database.PostgreSQL.Simple.Time.Internal.Parser
    Database.PostgreSQL.Simple.Time.Internal.Printer
    Database.PostgreSQL.Simple.TypeInfo.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/postgresql-simple-0.6.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/postgresql-simple-0.6.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/postgresql-simple-0.6.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-simple
hs-libraries:         HSpostgresql-simple-0.6.5.1-7DiheDmUALmJZpTHjvNinD
depends:
    Only-0.1-2ALIOaFTuVl17VyQ33BnR1
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    attoparsec-0.14.4-D6xkbFZLQBXDD0qvU7o55y base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-4psXWcL2Or6Ff92NkDcfKY
    containers-0.6.7 hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    postgresql-libpq-0.9.4.3-9EKBGqszgJV2gOXf0kEzu1
    scientific-0.3.8.0-6QoqQGQc0yZ1FsULZsdy9C template-haskell-2.19.0.0
    text-2.0.2 time-compat-1.9.8-FyLbpseVw0n8ujzOKdDd4B
    transformers-0.5.6.2 uuid-types-1.0.6-FrsVI2TWMUe2l6zd1aRiCM
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-simple/html/postgresql-simple.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-simple-0.6.5.1-107-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgresql-simple
version:              0.6.5.1
visibility:           public
id:                   postgresql-simple-0.6.5.1-8yWgBWN4PQ1Labl4qno5HB
key:                  postgresql-simple-0.6.5.1-8yWgBWN4PQ1Labl4qno5HB
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.
    (c) 2011-2018 Leon P Smith
    (c) 2018-2020 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Bryan O'\''Sullivan, Leon P Smith
synopsis:             Mid-Level PostgreSQL client library
description:
    Mid-Level PostgreSQL client library, forked from mysql-simple.

category:             Database
abi:                  58fa0feb7004e74870657bec87333fbb
exposed:              True
exposed-modules:
    Database.PostgreSQL.Simple Database.PostgreSQL.Simple.Arrays
    Database.PostgreSQL.Simple.Copy Database.PostgreSQL.Simple.Cursor
    Database.PostgreSQL.Simple.Errors
    Database.PostgreSQL.Simple.FromField
    Database.PostgreSQL.Simple.FromRow
    Database.PostgreSQL.Simple.HStore
    Database.PostgreSQL.Simple.HStore.Internal
    Database.PostgreSQL.Simple.Internal
    Database.PostgreSQL.Simple.LargeObjects
    Database.PostgreSQL.Simple.Newtypes
    Database.PostgreSQL.Simple.Notification
    Database.PostgreSQL.Simple.Ok Database.PostgreSQL.Simple.Range
    Database.PostgreSQL.Simple.SqlQQ Database.PostgreSQL.Simple.Time
    Database.PostgreSQL.Simple.Time.Internal
    Database.PostgreSQL.Simple.ToField Database.PostgreSQL.Simple.ToRow
    Database.PostgreSQL.Simple.Transaction
    Database.PostgreSQL.Simple.TypeInfo
    Database.PostgreSQL.Simple.TypeInfo.Macro
    Database.PostgreSQL.Simple.TypeInfo.Static
    Database.PostgreSQL.Simple.Types Database.PostgreSQL.Simple.Vector
    Database.PostgreSQL.Simple.Vector.Unboxed

hidden-modules:
    Database.PostgreSQL.Simple.Compat
    Database.PostgreSQL.Simple.HStore.Implementation
    Database.PostgreSQL.Simple.Internal.PQResultUtils
    Database.PostgreSQL.Simple.Time.Implementation
    Database.PostgreSQL.Simple.Time.Internal.Parser
    Database.PostgreSQL.Simple.Time.Internal.Printer
    Database.PostgreSQL.Simple.TypeInfo.Types

import-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/postgresql-simple-0.6.5.1

library-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/postgresql-simple-0.6.5.1

library-dirs-static:
    /usr/lib/ghc-9.6.7.20250817/site-local/postgresql-simple-0.6.5.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-simple
hs-libraries:         HSpostgresql-simple-0.6.5.1-8yWgBWN4PQ1Labl4qno5HB
depends:
    Only-0.1-EKDJd7lVV8nkLGYR4MAJC aeson-2.2.0.0-C0AkopVKntgCgZgm8TP6Wj
    attoparsec-0.14.4-LMUtUfKC5plL7ZZhgWxit1 base-4.18.3.0
    bytestring-0.11.5.4 case-insensitive-1.2.1.0-EV7LFLdw26GITlLZKOJrjF
    containers-0.6.7 hashable-1.4.7.0-17jkMnZLQLs4o2IKp4JpPo
    postgresql-libpq-0.9.5.0-CRLsCgEjZ1oGLCMGXDUWRQ
    scientific-0.3.8.0-FwKzA73aVbXJ5rDpcJgYmo template-haskell-2.20.0.0
    text-2.0.2 time-compat-1.9.8-7aGKPh3OcX5AMgxpl4DV5a
    transformers-0.6.1.0 uuid-types-1.0.6-L9Y6dI38zycBFxOZxyUWtz
    vector-0.13.2.0-BINMV7y6ibUKgFTnLXEi1A

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-simple/html/postgresql-simple.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-simple/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
